{-# LANGUAGE OverloadedStrings #-}
-- | Build time configuration used during code generation.
module GI.Freetype2.Config ( overrides, modules ) where

import qualified Data.Text as T
import Data.Text (Text)

-- | Overrides used when generating these bindings.
overrides :: Text
overrides = T.unlines
 [ ]

-- | Modules in this package
modules :: [Text]
modules =  [ "GI.Freetype2.Config"
 , "GI.Freetype2"
 , "GI.Freetype2.Structs"
 , "GI.Freetype2.Structs.Bitmap"
 , "GI.Freetype2.Structs.Face"
 , "GI.Freetype2.Structs.Library"]
